# Neuromuscular Risk Factors for Knee and Ankle Ligament Injuries in Male Youth Soccer Players

Paul J. Read \[1\]\[ •\] Jon L. Oliver \[2,7\]\[ •\] Mark B. A. De Ste Croix \[3\]\[ •\]
Gregory D. Myer \[4,5,6,8\]\[ •\] Rhodri S. Lloyd \[2,7\]

Published online: 8 February 2016
� Springer International Publishing Switzerland 2016

Abstract Injuriesreportedinmale youthsoccerplayersmost
commonly occur in the lower extremities, and include a high
proportion of ligament sprains at the ankle and knee with a
lower proportion of overuse injuries. There is currently a paucity of available literature that examines age- and sex-specific
injury risk factors for such injuries within youth soccer players.
Epidemiological data have reported movements that lead to
non-contact ligament injury include running, twisting and
turning, over-reaching and landing. Altered neuromuscular
control during these actions has been suggested as a key
mechanism in females and adult populations; however, data
available in male soccer players is sparse. The focus of this

article is to review the available literature and elucidate

prevalent risk factors pertaining to male youth soccer players
which may contribute to their relative risk of injury.

& Paul J. Read

<paul.read@stmarys.ac.uk>

1 School of Sport, Health and Applied Science, St Mary’s
University, Waldegrave Road, Twickenham, London
TW1 4SX, UK

2 Youth Physical Development Unit, School of Sport, Cardiff
Metropolitan University, Cardiff, UK

3 Exercise and Sport Research Centre, School of Sport and
Exercise, University of Gloucestershire, Gloucester, UK

4 Division of Sports Medicine, Cincinnati Children’s Hospital
Medical Center, Cincinnati, OH, USA

5 Department of Pediatrics and Orthopaedic Surgery, College
of Medicine, University of Cincinnati, Cincinnati, OH, USA

6 The Micheli Center for Sports Injury Prevention, Boston,
MA, USA

7 Sport Performance Research Institute, New Zealand
(SPRINZ), AUT University, Auckland, New Zealand

8 Department of Orthopaedics, University of Pennsylvania,
Philadelphia, PA, USA

Key Points

The occurrence of lower limb injuries, specifically
occurring at the knee and ankle, in male youth soccer
players is highly prevalent, with altered
neuromuscular control during dynamic activities
indicated as a potential injury mechanism.

Specific neuromuscular imbalances have been
identified as risk factors for ligamentous injuries
including quadriceps dominance, leg dominance,
ligament dominance, trunk dominance,

neuromuscular feed-forward muscle activation

patterns and dynamic stability.

Existing research suggests that heightening

neuromuscular control in the aforementioned areas

may reduce the risk of injury in male youth soccer
players; however, available data in this cohort are

sparse.

1 Introduction

The sport of soccer imposes high physiological demands
and an inherent risk of injury due to the repeated high
intensity movements such as jumping, cutting and contact
with opposition players when fatigued \[15\]. Injuries in
male youth soccer players occur mainly in the lower
extremities (71–80 %), with a low proportion (5 %) of
overuse injuries and a high proportion (20 %) of acute
traumatic ligament sprains at the ankle and knee \[35, 62,
65\]. More specifically, the medial collateral ligament
(MCL) and anterior talofibular ligament are the most
commonly reported injuries \[11, 62\].

## 123

1060 P. J. Read et al.

Altered neuromuscular control during dynamic activities
(e.g. running, cutting and landing) is indicated as a key
mechanism for lower limb ligament injuries \[22, 23\].
Deficits in neuromuscular control direct excessive stress to
the passive ligamentous structures, exceeding their tensile
threshold, resulting in mechanical failure \[37\]. Specific
neuromuscular imbalances have been identified for female
athletes and adult males including: quadriceps dominance

\[48\], leg dominance \[51\], ligament dominance \[21\], trunk
dominance \[24, 51\], neuromuscular activation patterns \[33\]
and dynamic stability \[64\]. The presence of these deficiencies does not indicate an explicit causative factor for
injury per se; however, it should be noted that ligamentous
injuries likely occur when active muscular restraints are
unable to adequately reduce joint torques during dynamic
movements involving deceleration and high forces \[9, 61\].
In spite of the growing body of evidence in adults and
young female athletes, there is a paucity of literature
available examining injury risk factors in male youth soccer players. Due to the physical demands of youth soccer,
the associated injury risk and the number of children and
adolescents who participate in the sport with an age-related
increase in incidence \[45, 62\], there is a clear need for
increased research in this cohort to identify age- and sexspecific injury risk factors \[2\]. This article reviews the
available literature and investigates key neuromuscular risk
factors that may contribute to their relative risk of injury.

2 Quadriceps Dominance

Disproportionate knee moments between recruitment of the
quadriceps and hamstrings may be reflective of an imbalance in force absorption \[51\]. Actions in soccer which
require rapid decelerations (such as landing, pivoting and
cutting) involve substantial eccentric muscle force contributions from the knee extensors, increasing the risk of noncontact ligamentous injuries \[67\]. The considerable anterior
shear of the tibia relative to the femur is counteracted by the
anterior cruciate ligament (ACL), MCL and co-activation of
the knee flexors \[8, 17\]. The functional hamstrings:quadriceps ratio has been shown to increase in post-pubertal
children and adolescents as a requirement for co-activation
of the hamstrings to reduce anterior tibial translation and
high shear forces of the quadriceps during high velocity
movements as a form of counterbalance \[16\]. In male youth
soccer players, alterations in the functional hamstring:quadriceps ratio (H:Q) may be present due to muscle
loading patterns that asymmetrically strengthen the
quadriceps during repetitive training and competitions \[29\].
This alters the reciprocal balance of strength and dynamic
stabilization around the knee as indicated by compromised
function of the hamstrings during high velocity actions \[29\].

## 123

Confounding factors such as fatigue and previous injury
also need to be considered within the remit of injury risk
factors as the final stages of a game appear to be a particular time of risk in male youth players \[62\]. In adults,
reports of a more quadriceps-dominant landing strategy
and reduced peak muscle activation of the tibialis anterior
and hamstrings \[57\], in addition to changes in the functional H:Q ratio \[68\], have been cited as plausible explanations. Neuromuscular inhibition of the hamstrings may
also be present following the occurrence of a hamstring
injury \[56\], and such injuries occur at regular frequencies
in elite male youth soccer \[35, 62\]. The knee flexors are
key antagonist muscles, are heavily involved with knee
joint stabilization and demonstrate greater deficits in
eccentric rather than concentric strength \[13, 34\]. Cumulatively, it could be conceived that reduced activation of
the hamstrings relative to the quadriceps increases injury
risk in male youth soccer players. Therefore, practitioners
should devise appropriate injury prevention strategies that
target deficits in knee flexor strength. Limited data are
available in youth populations; however, in collegiate
female athletes a 6-week programme of emphasized hamstring resistance training significantly increased the functional H:Q ratio to acceptable levels (\[1) for the reduction
of ACL injuries \[28\]. Significant improvements in sagittal
plane knee kinematics indicative of a reduced quadriceps
dominant landing strategy (greater initial contact knee
flexion) have also been observed following a short duration
(7 weeks) neuromuscular training programme that included
both dynamic balance and plyometric exercises \[50\]. The
authors suggested that the prescribed interventions could
have increased knee flexor co-contraction; however, muscle activation patterns were not measured. Further research

is warranted to examine the effects of such activities on

measures of quadriceps dominance in male youth soccer
players.

3 Leg Dominance

Leg dominance has been defined as an imbalance in
strength, coordination and control between the two lower
extremities \[48\]. A discrepancy in excess of 15 % has been
deemed a key predictor of injury \[13\]. Asymmetry places
additional stress on the weaker leg, compromising performance and predisposing athletes to various injuries during
cutting/landing activities \[27\]. This risk factor is inherent
to soccer, where preferred limb dominance is evident. For
example, Zebis et al. \[73\] identified that during a cutting
manoeuvre, all subjects who subsequently experienced an
ACL rupture in the following two competitive seasons
injured their preferred push-off leg. Additionally, analysis
of the distribution of non-contact ACL injuries in male

Neuromuscular Risk Factors in Youth Soccer 1061

players confirmed 74.1 % injured their dominant (kicking)
leg \[10\]. There is a paucity of data in youth players confirming the presence of asymmetry and associated injury
risk. One available study used the star excursion balance
test \[60\]. Logistic regression indicated that high school
athletes with an anterior right-left reach difference \[4 cm
represented a 2.5 times greater risk of lower extremity
injury. To the knowledge of the authors, no studies have
been conducted with male youth soccer players to examine
the relationship between limb dominance and prevalence of
injury.
In spite of the lack of available evidence to report the
relationship with injury, asymmetry has been reported in
male youth soccer players \[3, 14\]. Daneshjoo et al. \[14\]
measured isokinetic hamstring and quadriceps strength and
hip joint flexibility in young male professional soccer
players. Of the 36 players tested, all but one reported
musculoskeletal imbalances \[10 % and heightened levels
of dominant leg hip joint range of motion. In addition,
Atkins et al. \[3\] investigated limb asymmetry by examining
contralateral differences in peak ground reaction forces
during the deep squat exercise in elite male youth soccer
players. Based on chronological age, significant differences
were identified between limbs (p B 0.05) in all age groups
except for the under thirteens (U13s) and under seventeens
(U17s) (the youngest and oldest groups, respectively),
indicating that asymmetry increases during the period of
peak height velocity (PHV) and the early stages of adolescence. This time-point corresponds with a stage of
adolescent awkwardness, in which decrements in motor
skill performance are often evident resulting from rapid
gains in limb length \[39, 59\]. Further, elite male youth
soccer players experience more traumatic injuries in the
year of PHV \[70\], and total injury incidence is highest in
this period \[62, 65\]. An awareness of leg dominance and
the development of appropriate screening protocols will aid
practitioners to identify youth players who may be at a
greater risk of injury. Utilizing single limb tasks is preferred to bilateral variations due to their enhanced ability
and sensitivity for determining deficits in neuromuscular
control \[51\]. Furthermore, assessments of leg power across
multiple directions (vertical, horizontal and lateral) have
reported insignificant relationships between tests in the
various movement planes \[27, 41, 44\]. Testing athletes
across different directions may measure relatively independent leg-power qualities, thus utilizing a range of
assessments targeting multi-planar actions is recommended. When interpreting athlete test scores, practitioners
should also be cognizant that accurately determining an
asymmetry threshold to predict injury is challenging. Adult
data indicate a 15 % difference between limbs increases

injury risk; however, currently no research is available to
examine the relationship between asymmetry and injury

risk in male youth soccer players, and this requires further
investigation.

4 Ligament Dominance

Dynamic valgus alignment has been defined as a medial or
valgus collapse of the knee during tasks which involve hip
and knee flexion \[23, 48\]. Displacement primarily occurs in
the frontal plane from a combination of hip internal rotation, knee valgus and tibial external rotation \[33\]. This is
coupled with decreased knee and hip flexion angles and
pronation at the subtalar joint \[10\]. Such knee positions
indicative of reduced frontal plane control on ground
contact have been reported in male subjects who subsequently experienced an ACL injury \[58\]. Due to the
increased load on the MCL and ACL in this position,
greater valgus angles have been indicated as a predisposing
injury risk factor for athletes \[23\]. In male youth soccer,
incidence reports have confirmed that 17.1 % of all injuries
occur at the knee \[35, 47\], and the MCL accounts for
between 77 and 83 % of all knee ligament injuries \[47, 62\].
The knee is also the most frequent site of major injuries
(classified as \[4 weeks absence from match play) in this
population \[71\], most commonly ACL lesions (all of which
required surgery), followed by meniscal and MCL sprains.
Knee valgus has been a commonly associated risk factor
for non-contact ACL injury in female athletes \[23\]. During
the prepubescent period, similar valgus alignment has been
reported between boys and girls \[4, 19, 63\]. In a large
cohort study, Barber-Westin et al. \[5\] identified that during
a drop jump test, although boys (aged between 9 and
17 years) had greater mean ankle and knee separation
distances than aged-matched girls on take-off, a large
proportion of the boys displayed distinct lower limb valgus
alignment upon landing. No significant sex differences for
mean total medial knee displacement were present and
normalized medial knee displacement difference between
boys and girls aged 15 years was minimal. Therefore, this
risk factor may be present in both youth males and females.
However, caution should be applied to the findings of
Barber-Westin et al. \[5\], as sizeable variability was present
in the data; the study only used a single-plane camera setup which may have limited the accuracy of identifying
potential differences. These findings also conflict with
previous investigations that have reported that after the
onset of maturation, girls display greater medial knee displacement than boys \[22\].
During the prepubescent period, ACL injury occurrence
is less frequent \[69\]; however, the risk of ligament sprain
increases as youth approach adolescence \[1\]. Smaller stature, lower body mass and relatively slower velocities of
play involved in children’s sporting activities may help

## 123

1062 P. J. Read et al.

reduce the risk of injury in pre-pubertal athletes \[5\].
Cumulatively, the available data show that younger male
players will display greater levels of knee valgus than older
youths; however, these findings are not consistent across
the all investigations \[55\]. A lack of evidence currently
exists to describe knee angles during landing and cuttingbased tasks for male youth soccer players at different
stages of growth and maturation and their association with
injury risk. This requires further investigation to validate its
presence as a relevant risk factor for knee injury in this
cohort. However, due to the potential for increased injury
risk, young male soccer players, and specifically those who
demonstrate valgus alignment upon landing, should be
targeted to undertake a progressive and periodized integrative neuromuscular training (INT) programme comprised of general and specific activities including strengthbuilding, plyometrics, balance and agility \[28\]. This should
be completed in addition to their regular soccer practice
due to the beneficial effects of INT on lower extremity
kinematics \[50, 52, 53\].

5 Neuromuscular Feed-Forward Strategies

During actions such as landing from a jump or side cutting
in competitive match play, the time available for decision
making and postural repositioning is limited. These reactive tasks provide insufficient time to make the necessary
postural adjustments, resulting in compromised leg positioning and significantly greater loads on the knee joint \[7\].
Moreover, Krosshaug et al. \[33\] using in-vivo video analysis reported that the timing of non-contact ACL injury
ranged between 17 and 50 ms following initial ground
contact. This short timeframe does not provide a suitable period to utilize reflexive neuromuscular feedback
mechanisms, but rather relies on feed-forward muscle
activation. This serves to maintain joint integrity by providing early recruitment of the involved musculature prior
to loading to better enable force absorption and, in doing
so, reducing joint torques and ligamentous loadings \[6, 7,
23\]. Therefore, altered or imbalanced sequences of neuromuscular firing during dynamic actions occurring in soccer
such as landing or cutting may increase the risk of injury.
There is a paucity of research that has examined the
relationship between muscle pre-activation and injury risk
in paediatric populations. Available literature has compared muscle pre-activation in pre-pubescent boys (aged
9–11 years) and post-pubescent males (aged 19–29 years)
during a vertical jumping task \[12\]. Post-pubescent youth
displayed greater levels of hamstring activity and co-contraction ratio prior to landing. Conversely, greater hamstring activity post-landing and during initial contact to
maximum knee flexion was present in pre-pubertal

## 123

subjects, indicating greater co-contraction ratios postlanding than older subjects. Intuitively, this suggests that a
more efficient neuromuscular feed-forward strategy is
developed prior to landing as males mature to control
ground reaction forces and regulate anterior displacement
of the knee. Confirming this, research shows that
preparatory co-contraction ratios were two times higher in
adults compared to children in landing from a vertical jump
task \[66\]. Data also show that as children mature they
become more reliant on supra-spinal feed-forward input
and short latency stretch reflexes \[38\], suggesting that preactivation strategies are a learnt skill that develop with
maturation. During a period of adolescent awkwardness,
disrupted sequences of neuromuscular feed-forward muscle
recruitment may increase injury risk; re-establishing the
correct performance of fundamental motor skills and
landing mechanics is thus an important consideration for
practitioners responsible for youth-based exercise prescription. Furthermore, practitioners should consider the
inclusion of plyometric exercises to reduce the risk of
injury. Data are available in young female athletes that
show 6 weeks of plyometric training increased preparatory
muscle activation of the adductors and abductor-adductor

coactivation ratio, which was suggestive of a training-induced pre-active motor strategy \[20\]. Thus, while this
study utilized female subjects, it could be inferred that such
activities would also be beneficial for male youth soccer
players; however, this requires further investigation.

6 Dynamic Balance

Effective performance of both static and dynamic stability
tasks requires the integration of visual, vestibular and
proprioceptive inputs which provide an efferent response to
control the body’s centre of mass within its base of support

\[20\]. Deficits in postural control and reflex stabilization
have been reported in the assessment of subjects with
functional ankle instability via the calculation of time to
stabilization \[64\]. A delay in neural feedback responses,
which contribute to lower limb stability, may increase
injury risk highlighted by the timing of ACL injuries
17–50 ms after initial ground contact \[33\]. In male soccer
players, the physiological training effects of a warm-up
injury prevention programme have been reported and time
to stabilization in the training group was 90 ms faster than
the soccer training-only matched controls \[31\]. Therefore,
it can be implied that shorter muscle feedback responses
will enhance neuromuscular control via active restraint,
thus lowering injury risk.
Available data to confirm relationships between
impaired dynamic stability and injury risk in youth populations is sparse. Previous literature has suggested that

Neuromuscular Risk Factors in Youth Soccer 1063

maturation of the neurological, visual, vestibular and proprioceptive systems may lead to enhanced performance
during single leg balancing tasks \[46\]. Younger subjects
demonstrate greater postural sway during single leg balance maneuvers which may compromise stability \[46\]. In
male high school basketball players, higher postural sway
during unilateral balancing was also associated with
increased risk of ankle sprain \[42\]. Subjects who demonstrated greater sway experienced nearly seven times as
many ankle sprains as those with good balance. In male
youth soccer, ankle injuries account for 19 % of total injury
incidence \[11\] and the most common diagnosis is anterior
talofibular ligament sprain \[62\]. Improving dynamic balance has significantly reduced the risk of ankle sprains in
high school soccer and basketball players who performed a
series of single leg balance and squat exercises in both
stable and unstable conditions (risk ratio 0.56; 95 % confidence interval (CI) 0.33–0.95; P = 0.033) \[43\]. Moreover, youth male soccer players undertaking a
proprioception training intervention enhanced postural
stability indices in both anterior-posterior and medial-lateral directions on the star excursion balance test \[40\].
Additionally, a significant reduction in the number of knee
and ankle sprains was reported across the course of a
soccer season in these players in comparison to those who
only completed their normal soccer training \[40\]. Enhanced
trunk stabilization may also improve dynamic stability and
balance due to improved trunk motion control \[26\]. This
has been confirmed in male youth soccer players, whereby
an intervention consisting of trunk stabilization exercises
including quadruped contralateral raises, front planks, back
and side bridges enhanced performance during specified

reach directions of the star excursion balanced test and

single leg static balance tasks \[30\]. Cumulatively, the
available literature suggests that deficiencies in dynamic
stability may increase the risk of lower limb injuries in
male youth soccer players. Targeting these deficits using
appropriately prescribed balance and trunk stabilization
exercises may subsequently reduce this risk.

7 Trunk Dominance

Trunk dominance has been defined as an imbalance
between the inertial demands of the trunk and the ability of
the ‘core’ to resist perturbations to the centre of mass \[24,
51\]. This inability to dissipate force effectively results in
excessive trunk motion primarily in the frontal plane and
increased ground reaction forces and knee joint torques

\[25\]. When distal segments are fixed during closed chain
sporting actions, motion at more proximal segments will
influence the kinetics and kinematics of other segments in
the chain \[36\]. A key action of the abdominal musculature

is to provide adequate control of the pelvis due to increases
in femoral internal rotation and adduction which may be
coupled with increased anterior pelvic tilt \[32\]. Active
proprioceptive repositioning of the trunk has also predicted
knee injury status with 90 % sensitivity and 56 % specificity in female athletes \[72\]. Thus, reduced pre-activation
of the trunk may result in a loss of control of the body’s

centre of mass and can be considered essential for con
trolling excessive spinal motions which may contribute to
altered biomechanics of the lower limbs during dynamic
movements in soccer.

There is currently a paucity of literature pertaining to
measures of core stability, trunk dominance and injury
incidence in youth male soccer players. While the aforementioned assessments \[72\] have demonstrated favourable

results, it should be considered that such measures were
derived during artificial conditions and postures in which
the pelvis is immobilized, limiting contributions from more
distal musculature. Ecological validity may be questioned
and the highly specialized and costly equipment will likely
limit application to larger scale youth athlete screening
programmes. Alternative field-based trunk muscle endurance assessments also contain ecological validity concerns
due to their prolonged isometric actions and non-functionality. This is confounded by data reporting weakmoderate relationships (intra-class correlation coefficient
range = 0.37–0.62) between performance on isometric
trunk endurance tests and a range of athletic measures \[54\].
Moreover, Leetun et al. \[36\] analyzed isometric trunk
endurance tests and additional measures of hip abduction
and external rotation strength, identifying that hip external
rotation strength was the only useful predictor of injury
status (odds ratio 0.86; 95 % CI 0.77–0.097). Therefore,
further investigation is required to elucidate if trunk dysfunction is a prevalent risk factor in youth male soccer
players. In addition, appropriate trunk dominant neuromuscular control tests are needed to accurately measure
potential deficits that may predispose athletes to a greater
risk of injury.

8 Injury Risk Factor Hierarchical Model

Following the identification of prevalent injury risk factors,
the authors propose a systematic model to screen male
youth players and subsequently develop individualized
programmes to reduce their relative risk of knee and ankle
injuries (Fig. 1). Each risk factor is linked to a neuromuscular screening assessment and target exercises are
then selected to improve relevant neuromuscular control
deficits. It is beyond the scope of this review to discuss
each assessment listed here; however, practitioners are
encouraged to examine comprehensive reviews that discuss

## 123

1064 P. J. Read et al.

Fig. 1 Knee and ankle ligament injury neuromuscular risk factor
hierarchical model. The top tier of the model includes identification of
the associated neuromuscular risk factors for knee and ankle ligament
injuries. Practitioners are then required to select appropriate assessments that are able to detect functional deficits assisting in the early
identification of players at high risk (tier 2 of the model). The final

their application \[48, 51\] and to utilize assessments that:
(1) focus on mechanisms and associated risk factors of
injury, (2) are able to detect functional deficits assisting in
the early identification of players at high risk, and (3)
demonstrate suitable validity and reliability. Also, practitioners may wish to assess their players’ movement abilities under conditions of fatigue to determine changes in
neuromuscular control. In male youth soccer, injuries occur
more frequently towards the end of the first and second
halves, respectively \[62\]. Solely screening players in a nonfatigued state may not accurately identify those individuals

whose movement mechanics deteriorate towards the end of

a match, affecting their relative risk of injury.
The final step requires the selection of appropriate
exercises that are associated with each test. It is proposed
that following an appropriate training intervention, neuromuscular deficits can be reduced, lowering injury risk. In
selecting exercises to reduce injury risk, practitioners are
advised to consider INT \[52\]. The integration of such
activities that develop fundamental movement skills should
be initiated during pre-adolescence and maintained through
adolescence to enhance skill-related fitness and reduce the
risk of sports-related injury \[18, 49, 53\]. Periodized INT
programmes included during the pre- and off-season periods are also critical, especially for youth soccer players
who engage in specialized sports practice where exposure

## 123

step involves the selection of appropriate exercises that target each of
the respective neuromuscular risk factors. It is proposed that
following an appropriate training intervention, test performance will
improve and subsequent neuromuscular deficits can be reduced,
lowering injury risk

to a wide range of developmental motor skill activities is
limited \[52\].

9 Conclusions

The occurrence of lower limb injuries in male youth soccer
players is highly prevalent, with risk increasing as players
grow and mature. This review has identified neuromuscular
imbalances for common injuries in male youth soccer
providing an overview of the available paediatric literature.
Existing research suggests that heightening neuromuscular
control in the aforementioned areas may reduce the risk of
injury in male youth soccer players; however, practitioners
should be cognizant that available data in this cohort are
sparse. A hierarchical injury risk factor model has also
been proposed to provide practitioners with a systematic
model to screen youth players and determine their level of
risk. Hypothetically, this information can then be used to
develop individualized programmes that target deficits in

neuromuscular control.

Compliance with Ethical Standards

Funding No sources of funding were used to assist in the preparation of this article. One author (Gregory Myer) would like to
acknowledge funding support from National Institutes of Health
Grants R21-AR065068.

Neuromuscular Risk Factors in Youth Soccer 1065

Conflicts of interest Paul Read, Jon Oliver, Mark de Ste Croix,
Gregory Myer and Rhodri Lloyd declare that they have no conflicts of
interest relevant to the content of this review.

References

1. Adrim TA, Cheng TL. Overview of injuries in the young athlete.
   Sports Med. 2003;33:75–81.

1. Alentorn-Geli E, Mendiguchıa J, Samuelsson K, et al. Prevention
   of anterior cruciate ligament injuries in sports—part I: systematic
   review of risk factors in male athletes. Knee Surg Sports Traumatol Arthrosc. 2014;22:3–15.

1. Atkins SJ, Hesketh C, Sinclair JK. The presence of bilateral
   imbalance of the lower limbs in elite youth soccer players of
   different ages. J Strength Cond Res. 2015 (in press).

1. Barber-Westin SD, Galloway M, Noyes FR, et al. Assessment of
   lower limb neuromuscular control in prepubescent athletes. Am J
   Sports Med. 2005;33:1853–60.

1. Barber-Westin D, Noyes FR, Galloway M. Jump-land characteristics and muscle strength development in young athletes. A
   gender comparison of 1140 athletes 9 to 17 years. Am J Sports
   Med. 2006;34:375–84.

1. Beard DJ, Kyberd PJ, Fergusson CM, et al. Proprioception after
   rupture of the anterior cruciate ligament. An objective indication
   of the need for surgery? J Bone Joint Surg. 1993;75:311–5.

1. Besier TF, Lloyd DG, Ackland TR, et al. Anticipatory effects on
   knee joint loading during running and cutting maneuvers. Med
   Sci Sport Exerc. 2001;33:1176–81.

1. Beynnon B, Howe JG, Pope MH, et al. The measurement of ACL
   strain in-vitro. Int Orthop. 1992;16:1–12.

1. Beynnon BD, Fleming BC. Anterior cruciate ligament strain invivo: a review of previous work. J Biomech. 1998;31:519–25.

1. Brophy R, Silvers H, Gonzales T, et al. Gender influences: the
   role of leg dominance in ACL injury among soccer players. Br J
   Sports Med. 2010;44:694–7.

1. Cloke D, Spencer S, Hodson A, et al. The epidemiology of ankle
   injuries occurring in English Football Association academies. Br
   J Sports Med. 2009;43:1119–25.

1. Croce RV, Russell PJ, Swartz EE, et al. Knee muscular response
   strategies differ by developmental level but not gender during
   jump landing. Electromyogr Clin Neurophysiol. 2004;44:339–48.

1. Crosier JL, Crelaard JM. Hamstring muscle tear with recurrent complaints: an isokinetic profile. Isokinet Exerc Sci. 2000;8:175–80.

1. Daneshjoo A, Rahnama N, Mokhtar AH, et al. Bilateral and unilateral asymmetries of isokinetic strength and flexibility in male
   young professional soccer players. J Hum Kinet. 2013;36:45–53.

1. Daniel DM, Stone ML, Dobson BE, et al. Fate of the ACLinjured patient: a prospective outcome study. Am J Sports Med.
   1994;22:632–44.

1. De Ste Croix MBA. Advances in paediatric strength assessment:
   changing our perspective on strength development. J Sports Sci
   Med. 2007;6:292–304.

1. Draganich LF, Vahey JW. An in-vitro study of ACL strain
   induced by quadriceps and hamstring forces. J Orthop Res.
   1990;8:57–63.

1. Faigenbaum AD, Farrell A, Fabiano M, et al. Effects of integrative neuromuscular training on fitness performance in children. Pediatr Exerc Sci. 2011;23:573–84.

1. Ford KR, Shapiro R, Myer GD, et al. Longitudinal sex differences during landing in knee abduction in young athletes. Med
   Sci Sports Exerc. 2010;42:1923–31.

1. Guskiewicz KM, Perrin DH, Gansneder B. Effect of mild head
   injury on postural stability in athletes. J Athl Train.
   1996;31:300–6.

1. Hewett TE, Paterno MV, Myer GD. Strategies for enhancing
   proprioception and neuromuscular control of the knee. Clin
   Orthop. 2002;402:76–94.

1. Hewett TE, Myer GD, Ford KR. Decrease in neuromuscular
   control about the knee with maturation in female athletes. J Bone

Joint Surg Am. 2004;86:1601–8.
23\. Hewett TE, Myer GD, Ford KR, et al. Biomechanical measures of
neuromuscular control and valgus loading of the knee predict
anterior cruciate ligament injury risk in female athletes: a
prospective study. Am J Sports Med. 2005;33:492–501.
24\. Hewett TE, Ford KR, Myer GD, et al. Effect of puberty and
gender on landing force and jump height. Med Sci Sports Exerc.
2005;37:S66.
25\. Hewett T, Johnson D. ACL prevention programs: fact or fiction?
Orthopedics. 2010;33:36–9.
26\. Hewett TE, Myer GD. The mechanistic connection between the
trunk, knee, and anterior cruciate ligament injury. Exerc Sport Sci
Rev. 2011;39:161–6.
27\. Hewit J, Cronin J, Hume P. Multidirectional leg asymmetry
assessment in sport. Strength Cond J. 2012;34:82–6.
28\. Holcomb WR, Rublet MD, Lee HJ, et al. Effect of hamstringemphasized resistance training on hamstring: quadriceps strength
ratios. J Strength Cond Res. 2007;21:41–7.
29\. Iga J, George K, Lees A, et al. Cross-sectional investigation of
indices of isokinetic leg strength in youth soccer players and
untrained individuals. Scand J Med Sci Sports. 2009;19:714–9.
30\. Imai A, Kaneoka K, Okubo Y, et al. Effects of two types of trunk
exercises on balance and athletic performance in youth soccer
players. Int J Sports Phys Ther. 2014;9:47–57.
31\. Imprezzilini F, Bizzini M, Dvorak J, et al. Physiological and
performance responses to the FIFA 11? (part 2): a randomised
control trial on the training effects. J Sport Sci.
2013;31:1491–502.
32\. Ireland ML. The female ACL: why is it more prone to injury?
Orthop Clin North Am. 2002;33:637–51.
33\. Krosshaug T, Nakamae A, Boden BP, et al. Mechanisms of
anterior cruciate ligament injury in basketball: video analysis of
39 cases. Am J Sports Med. 2007;35:359–67.
34\. Lee TQ, Anzel SH, Bennett KA, et al. The influence of fixed
rotational deformities of the femur on the patellofemoral contact
pressures in human cadaver knees. Clin Orthop. 1994;302:69–74.
35\. Le Gall F, Carling C, Reilly T, et al. Incidence of injuries in elite
French youth soccer players; a 10-season study. Am J Sports
Med. 2006;34:928–38.
36\. Leetun D, Ireland M, Wilson J, et al. Core stability measures as
risk factors for lower extremity injury in athletes. Med Sci Sport
Exerc. 2004;36:926–34.
37\. Li G, Rudy TW, Allen C, et al. Effect of combined axial compressive and anterior tibial loads on in situ forces in the anterior
cruciate ligament: a porcine study. J Orthop Res. 1998;16:122–7.
38\. Lloyd RS, Oliver JL, Hughes MG, et al. Age-related differences
in the neural regulation of stretch–shortening cycle activities in
male youths during maximal and sub-maximal hopping. J Electromyogr Kinesiol. 2012;22:37–43.
39\. Lloyd RS, Oliver JL, Faigenbaum AD, et al. Chronological age
vs. biological maturation: implications for exercise programming
in youth. J Strength Cond Res. 2014;28:1454–64.
40\. Malliou P, Gioftsidou A, Pafis G, et al. Proprioceptive training
(balance exercises) reduces lower extremity injuries in young
soccer players. J Back Musculoskelet Rehabil. 2004;17:101–4.
41\. Maulder P, Cronin J. Horizontal and vertical jump assessment:
reliability, asymmetry, discriminative and predictive ability. Phys
Ther Sport. 2005;6:74–82.
42\. McGuine TA, Greene JJ, Best T, et al. Balance as a predictor of
ankle injuries in high school basketball players. Clin J Sports
Med. 2000;10:239–44.

## 123

1066 P. J. Read et al.

43. McGuineTA, Keene JS. The effect of a balance training program
    on the risk of ankle sprains in high school athletes. Am J Sports
    Med. 2006;34:1103–11.
01. Meylan C, McMaster T, Cronin J, et al. Single-leg lateral, horizontal, and vertical jump assessment: reliability, interrelationships, and ability to predict sprint and change-of-direction
    performance. J Strength Cond Res. 2009;23:1140–7.
01. Michaud PA, Renaud A, Narring F. Sports activities related to
    injuries? A survey among 9–19 year olds in Switzerland. Inj Prev.
    2001;7:41–5.
01. Mickle KJ, Munro BJ, Steele JR. Gender and age affect balance
    performance in primary school-aged children. J Sci Med Sport.
    2011;14:243–8.
01. Moore O, Cloke DJ, Avery PJ, et al. English Premiership
    Academy knee injuries: lessons from a 5 year study. J Sports Sci.
    2011;29:1535–44.
01. Myer GD, Ford KR, Hewett TE. Rationale and clinical techniques for ACL injury prevention among female athletes. J Athl
    Train. 2004;39:352–64.
01. Myer GD, Ford KR, Palumbo JP, et al. Neuromuscular training
    improves performance and lower extremity biomechanics in
    female athletes. J Strength Cond Res. 2005;19:51–60.
01. Myer GD, Ford KR, McLean SG, et al. The effects of plyometric
    versus dynamic stabilization and balance training on lower
    extremity biomechanics. Am J Sports Med. 2006;34:445–55.
01. Myer GD, Brent JL, Ford KR, et al. Real-time assessment and
    neuromuscular training feedback techniques to prevent ACL
    injury in female athletes. Strength Cond J. 2011;33:21–35.
01. Myer GD, Faigenbaum AD, Chu DA, et al. Integrative training
    for children and adolescents: techniques and practices for
    reducing sports-related injuries and enhancing athletic performance. Phys Sportsmed. 2011;39:74–84.
01. Myer GD, Faigenbaum AD, Ford KR, et al. When to initiate
    integrative neuromuscular training to reduce sports-related injuries in youth? Curr Sports Med Rep. 2011;10:155–66.
01. Nesser TW, Huxel KC, Tincher JL, et al. The relationship
    between core stability and performance in Division I football
    players. J Strength Cond Res. 2008;22:1750–4.
01. Noyes FR, Barber-Westin SD, Fleckenstein C, et al. The dropjump screening test: difference in lower limb control by gender
    and effect of neuromuscular training in female athletes. Am J
    Sports Med. 2005;33:197–207.
01. Opar D, Timmins R, Dear N, et al. The role of neuromuscular
    inhibition in hamstring strain injury recurrence. J Electromyogr
    Kinesiol. 2013;23:523–30.
01. Padua D, Arnold B, Perrin D, et al. Fatigue, vertical leg stiffness
    and stiffness control strategies in males and females. J Athl Train.
    2006;41:294–304.

## 123

58. Padua DA, Marshall SW, Boling MC, et al. The landing error
    scoring system (LESS) is a valid and reliable clinical assessment
    tool of jump-landing biomechanics. Am J Sports Med.
    2009;37:1996–2002.
01. Philippaerts RM, Vaeyens R, Janssens M, et al. The relationship
    between peak height velocity and physical performance in youth
    soccer players. J Sports Sci. 2006;24:221–30.
01. Plisky PJ, Rauh MJ, Kaminski TW, et al. Star Excursion Balance
    Test as a predictor of lower extremity injury in high school
    basketball players. J Orthop Sports Phys Ther. 2006;36:911–9.
01. Powell JW, Barber-Foss KD. Sex related injury patterns among
    selected high school sports. Am J Sports Med. 2000;28:385–91.
01. Price RJ, Hawkins RD, Hulse MA, et al. The Football Association and medical research programme: an audit of injuries in
    academy youth football. Br J Sports Med. 2004;38:466–71.
01. Quatman CE, Ford KR, Myer GD, et al. Maturation leads to
    gender differences in landing force and vertical jump performance: a longitudinal study. Am J Sports Med. 2005;34:1–8.
01. Ross S, Guskiwicz K. Assessment tools for identifying functional
    limitations associated with functional ankle instability. J Athl
    Train. 2008;43:44–50.
01. Rumpf M, Cronin J. Injury incidence, body site, and severity in
    soccer players aged 6–18 years: implications for injury prevention. Strength Cond J. 2012;34:20–31.
01. Russell PJ, Croce RV, Swart EE, et al. Knee muscle activation
    during landings: developmental and gender comparisons. Med
    Sci Sports Exerc. 2007;39:159–69.
01. Simonsen EB, Magnusson SP, Bencke J, et al. Can the hamstring
    muscles protect the anterior cruciate ligament during a side-cutting maneuver? Scand J Med Sci Sports. 2000;10:78–84.
01. Small K, McNaughton L, Greig M, et al. The effects of multidirectional soccer-specific fatigue on markers of hamstring injury
    risk. J Sci Med Sport. 2010;13:120–6.
01. Tursz A, Crost M. Sports related injuries in children: a study of
    their characteristics, frequency and severity with comparison to
    other accidental injuries. Am J Sports Med. 1986;14:294–9.
01. Van der Sluis A, Elferink-Gemser MT, Coelho-e-Sliva MJ, et al.
    Sports injuries aligned to peak height velocity in talented pubertal
    soccer players. Int J Sports Med. 2014;35:351–5.
01. Volpi P, Pozzoni R, Galli M. The major traumas in youth football. Knee Surg Sports Traumatol Arthrosc. 2003;11:399–402.
01. Zazulak BT, Hewett TE, Reeves NB, et al. The effects of core
    proprioception on knee injury: a prospective biomechanical epidemiological study. Am J Sports Med. 2007;35:368–73.
01. Zebis MK, Andersen LL, Bencke J, et al. Identification of athletes
    at future risk of ACL ruptures by neuromuscular screening. Am J
    Sports Med. 2009;37:1967–73.
